@@ -1,22 +1,9 @@
 /*
-    This file is part of kdev-python, the python language plugin for KDevelop
-    Copyright (C) 2012  Sven Brauch <svenbrauch@googlemail.com>
+    SPDX-FileCopyrightText: 2012 Sven Brauch <svenbrauch@googlemail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include <QTimer>
 #include <QApplication>
 
@@ -26,6 +13,7 @@
 #include <debugger/framestack/framestackmodel.h>
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
+#include <util/environmentprofilelist.h>
 
 #include "debugsession.h"
 #include "pdbframestackmodel.h"
@@ -52,13 +40,15 @@ static QByteArray debuggerOutputEnd = "<<<__KDEVPYTHON_END___DEBUGGER_OUTPUT";
 
 namespace Python {
 
-DebugSession::DebugSession(QStringList program, const QUrl &workingDirectory) :
+DebugSession::DebugSession(QStringList program, const QUrl &workingDirectory,
+    const QString& envProfileName) :
     IDebugSession()
     , m_breakpointController(nullptr)
     , m_variableController(nullptr)
     , m_frameStackModel(nullptr)
     , m_workingDirectory(workingDirectory)
-    , m_nextNotifyMethod(0)
+    , m_envProfileName(envProfileName)
+    , m_nextNotifyMethod(nullptr)
     , m_inDebuggerData(0)
 {
     qCDebug(KDEV_PYTHON_DEBUGGER) << "creating debug session";
@@ -91,6 +81,17 @@ void DebugSession::start()
     m_debuggerProcess->setOutputChannelMode(KProcess::SeparateChannels);
     m_debuggerProcess->blockSignals(true);
     m_debuggerProcess->setWorkingDirectory(m_workingDirectory.path());
+
+    const KDevelop::EnvironmentProfileList environmentProfiles(KSharedConfig::openConfig());
+    const auto environment = environmentProfiles.variables(m_envProfileName);
+
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    for(auto i = environment.cbegin(); i != environment.cend(); i++ )
+    {
+        env.insert(i.key(), i.value());
+    }
+    m_debuggerProcess->setProcessEnvironment(env);
+
     connect(m_debuggerProcess, &QProcess::readyReadStandardOutput, this, &DebugSession::dataAvailable);
     connect(m_debuggerProcess, SIGNAL(finished(int)), this, SLOT(debuggerQuit(int)));
     connect(this, &DebugSession::debuggerReady, this, &DebugSession::checkCommandQueue);
@@ -99,9 +100,9 @@ void DebugSession::start()
     m_debuggerProcess->waitForStarted();
     auto dir = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                       "kdevpythonsupport/debugger/", QStandardPaths::LocateDirectory);
-    InternalPdbCommand* path = new InternalPdbCommand(0, 0,
+    InternalPdbCommand* path = new InternalPdbCommand(nullptr, nullptr,
         "import sys; sys.path.append('"+dir+"')\n");
-    InternalPdbCommand* cmd = new InternalPdbCommand(0, 0, "import __kdevpython_debugger_utils\n");
+    InternalPdbCommand* cmd = new InternalPdbCommand(nullptr, nullptr, "import __kdevpython_debugger_utils\n");
     addCommand(path);
     addCommand(cmd);
     updateLocation();
@@ -163,7 +164,7 @@ void DebugSession::dataAvailable()
                                                     << "  " + i18n("You can now inspect the status of the program after it exited.")
                                                     << "  " + i18n("The debugger will silently stop when the next command is triggered.")
                                                     << "*****");
-                InternalPdbCommand* cmd = new InternalPdbCommand(0, 0, "import __kdevpython_debugger_utils\n");
+                InternalPdbCommand* cmd = new InternalPdbCommand(nullptr, nullptr, "import __kdevpython_debugger_utils\n");
                 addCommand(cmd);
             }
         }
@@ -235,7 +236,7 @@ void DebugSession::notifyNext()
         qCDebug(KDEV_PYTHON_DEBUGGER) << "notify called, but nothing to notify!";
     }
     m_buffer.clear();
-    m_nextNotifyMethod = 0;
+    m_nextNotifyMethod = nullptr;
     m_nextNotifyObject.clear();
 }
 
@@ -339,7 +340,7 @@ void DebugSession::runToCursor()
         if ( cursor.isValid() ) {
             // TODO disable all other breakpoints
             QString temporaryBreakpointLocation = doc->url().path() + ':' + QString::number(cursor.line() + 1);
-            InternalPdbCommand* temporaryBreakpointCmd = new InternalPdbCommand(0, 0, "tbreak " + temporaryBreakpointLocation + '\n');
+            InternalPdbCommand* temporaryBreakpointCmd = new InternalPdbCommand(nullptr, nullptr, "tbreak " + temporaryBreakpointLocation + '\n');
             addCommand(temporaryBreakpointCmd);
             addSimpleInternalCommand("continue");
             updateLocation();
@@ -390,7 +391,7 @@ void DebugSession::clearObjectTable()
 void DebugSession::addSimpleUserCommand(const QString& cmd)
 {
     clearObjectTable();
-    UserPdbCommand* cmdObject = new UserPdbCommand(0, 0, cmd + '\n');
+    UserPdbCommand* cmdObject = new UserPdbCommand(nullptr, nullptr, cmd + '\n');
     Q_ASSERT(cmdObject->type() == PdbCommand::UserType);
     addCommand(cmdObject);
 }
@@ -398,7 +399,7 @@ void DebugSession::addSimpleUserCommand(const QString& cmd)
 void DebugSession::addSimpleInternalCommand(const QString& cmd)
 {
     Q_ASSERT( ! cmd.endsWith('\n') );
-    InternalPdbCommand* cmdObject = new InternalPdbCommand(0, 0, cmd + '\n');
+    InternalPdbCommand* cmdObject = new InternalPdbCommand(nullptr, nullptr, cmd + '\n');
     addCommand(cmdObject);
 }
 
@@ -406,7 +407,7 @@ void DebugSession::runImmediately(const QString& cmd)
 {
     Q_ASSERT(cmd.endsWith('\n'));
     if ( state() == ActiveState ) {
-        m_nextNotifyMethod = 0;
+        m_nextNotifyMethod = nullptr;
         m_nextNotifyObject.clear(); // TODO is this correct?
         qCDebug(KDEV_PYTHON_DEBUGGER) << "interrupting debugger";
         INTERRUPT_DEBUGGER;
@@ -415,7 +416,7 @@ void DebugSession::runImmediately(const QString& cmd)
         updateLocation();
     }
     else {
-        addCommand(new InternalPdbCommand(0, 0, cmd));
+        addCommand(new InternalPdbCommand(nullptr, nullptr, cmd));
     }
 }
 
@@ -474,16 +475,28 @@ void DebugSession::locationUpdateReady(QByteArray data) {
 void DebugSession::stopDebugger()
 {
     m_commandQueue.clear();
-    InternalPdbCommand* cmd = new InternalPdbCommand(0, 0, "quit\nquit\n");
+    InternalPdbCommand* cmd = new InternalPdbCommand(nullptr, nullptr, "quit\nquit\n");
     addCommand(cmd);
     setState(StoppingState);
     if ( ! m_debuggerProcess->waitForFinished(200) ) {
         m_debuggerProcess->kill();
     }
+    qCDebug(KDEV_PYTHON_DEBUGGER) << "stopped debugger";
+    finalizeState();
+}
+
+void DebugSession::killDebuggerNow()
+{
+    qCDebug(KDEV_PYTHON_DEBUGGER) << "killing debugger now";
+    m_debuggerProcess->kill();
+    finalizeState();
+}
+
+void DebugSession::finalizeState()
+{
     m_commandQueue.clear();
-    m_nextNotifyMethod = 0;
+    m_nextNotifyMethod = nullptr;
     m_nextNotifyObject.clear();
-    qCDebug(KDEV_PYTHON_DEBUGGER) << "killed debugger";
     setState(IDebugSession::EndedState);
 }
 
